@@ -69,7 +69,7 @@ def join_image(img, p):
         for h in range(_w % a):
             imgl[h + (_w - _w % a), j + (_h - _h % a)] = p[x]
             x += 1
-def bytes2image(config):
+def bytes2image(config, directory=""):
 	pixels = []
 	info = config["info"]
 	name = config["name"]
@@ -99,12 +99,12 @@ def bytes2image(config):
 	del pixels 
 	del info
 	print(f"[*] saving {name}")
-	base.save(name)
+	base.save(directory+name)
 	del name
 	del base
 	return True
 class pycat:
-	def decodeSC(file, use_disk=False):
+	def decodeSC(file, use_disk=False,directory=""):
 		m = memory(b'')
 		m.mem = open(file, "rb")
 		temp = open(file, "rb")
@@ -191,10 +191,10 @@ class pycat:
 				if not use_disk:
 					sc = memory(decompressed)
 				else:
-					s = open("temp.sb","wb")
+					s = open(directory+"temp.sb","wb")
 					s.write(decompressed)
 					s.close()
-					s = open("temp.sb","rb")
+					s = open(directory+"temp.sb","rb")
 					sc = memory(b'')
 					sc.mem.close()
 					sc.mem = s
@@ -218,7 +218,7 @@ class pycat:
 								pixels.append(sc.readPixel(info[2]))
 							img = {"info":info,"name":name,"pixels":pixels}
 							try:
-								if not bytes2image(img):
+								if not bytes2image(img, directory):
 									index -= 1
 								print()
 							except:
@@ -230,7 +230,7 @@ class pycat:
 				sc.free()
 				del sc
 				if use_disk:
-					os.remove("temp.sb")
+					os.remove(directory+"temp.sb")
 			except:
 				print(traceback.format_exc())
 				pass
